@@ -21,10 +21,11 @@
  * @file
  */
 
-use MediaWiki\Auth\AuthManager;
 use MediaWiki\Auth\AuthenticationRequest;
 use MediaWiki\Auth\AuthenticationResponse;
+use MediaWiki\Auth\AuthManager;
 use MediaWiki\Logger\LoggerFactory;
+use MediaWiki\MediaWikiServices;
 
 /**
  * Unit to authenticate log-in attempts to the current wiki.
@@ -107,13 +108,15 @@ class ApiLogin extends ApiBase {
 		}
 
 		$authRes = false;
-		$context = new DerivativeContext( $this->getContext() );
 		$loginType = 'N/A';
 
 		// Check login token
 		$token = $session->getToken( '', 'login' );
-		if ( $token->wasNew() || !$params['token'] ) {
+		if ( !$params['token'] ) {
 			$authRes = 'NeedToken';
+		} elseif ( $token->wasNew() ) {
+			$authRes = 'Failed';
+			$message = ApiMessage::create( 'authpage-cannot-login-continue', 'sessionlost' );
 		} elseif ( !$token->match( $params['token'] ) ) {
 			$authRes = 'WrongToken';
 		}
@@ -130,7 +133,7 @@ class ApiLogin extends ApiBase {
 				$session = $status->getValue();
 				$authRes = 'Success';
 				$loginType = 'BotPassword';
-			} elseif ( !$botLoginData[2] ||
+			} elseif (
 				$status->hasMessage( 'login-throttled' ) ||
 				$status->hasMessage( 'botpasswords-needs-reset' ) ||
 				$status->hasMessage( 'botpasswords-locked' )
@@ -141,11 +144,12 @@ class ApiLogin extends ApiBase {
 					'BotPassword login failed: ' . $status->getWikiText( false, false, 'en' )
 				);
 			}
+			// For other errors, let's see if it's a valid non-bot login
 		}
 
 		if ( $authRes === false ) {
 			// Simplified AuthManager login, for backwards compatibility
-			$manager = AuthManager::singleton();
+			$manager = MediaWikiServices::getInstance()->getAuthManager();
 			$reqs = AuthenticationRequest::loadRequestsFromSubmission(
 				$manager->getAuthenticationRequests( AuthManager::ACTION_LOGIN, $this->getUser() ),
 				[
@@ -155,7 +159,7 @@ class ApiLogin extends ApiBase {
 					'rememberMe' => true,
 				]
 			);
-			$res = AuthManager::singleton()->beginAuthentication( $reqs, 'null:' );
+			$res = $manager->beginAuthentication( $reqs, 'null:' );
 			switch ( $res->status ) {
 				case AuthenticationResponse::PASS:
 					if ( $this->getConfig()->get( 'EnableBotPasswords' ) ) {
@@ -194,9 +198,9 @@ class ApiLogin extends ApiBase {
 
 				// Deprecated hook
 				$injected_html = '';
-				Hooks::run( 'UserLoginComplete', [ &$user, &$injected_html, true ] );
+				$this->getHookRunner()->onUserLoginComplete( $user, $injected_html, true );
 
-				$result['lguserid'] = intval( $user->getId() );
+				$result['lguserid'] = (int)$user->getId();
 				$result['lgusername'] = $user->getName();
 				break;
 
@@ -220,15 +224,15 @@ class ApiLogin extends ApiBase {
 				);
 				break;
 
+			// @codeCoverageIgnoreStart
+			// Unreachable
 			default:
 				ApiBase::dieDebug( __METHOD__, "Unhandled case value: {$authRes}" );
+			// @codeCoverageIgnoreEnd
 		}
 
 		$this->getResult()->addValue( null, 'login', $result );
 
-		if ( $loginType === 'LoginForm' && isset( LoginForm::$statusCodes[$authRes] ) ) {
-			$authRes = LoginForm::$statusCodes[$authRes];
-		}
 		LoggerFactory::getInstance( 'authevents' )->info( 'Login attempt', [
 			'event' => 'login',
 			'successful' => $authRes === 'Success',
@@ -267,8 +271,6 @@ class ApiLogin extends ApiBase {
 
 	protected function getExamplesMessages() {
 		return [
-			'action=login&lgname=user&lgpassword=password'
-				=> 'apihelp-login-example-gettoken',
 			'action=login&lgname=user&lgpassword=password&lgtoken=123ABC'
 				=> 'apihelp-login-example-login',
 		];
@@ -288,8 +290,8 @@ class ApiLogin extends ApiBase {
 			'status' => $response->status,
 		];
 		if ( $response->message ) {
-			$ret['message'] = $response->message->inLanguage( 'en' )->plain();
-		};
+			$ret['responseMessage'] = $response->message->inLanguage( 'en' )->plain();
+		}
 		$reqs = [
 			'neededRequests' => $response->neededRequests,
 			'createRequest' => $response->createRequest,
